==> huaweicloudsdkiamaccessanalyzer-3.1.91-py2.py3-none-any.whl: huaweicloudsdkiamaccessanalyzer/v1/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

from huaweicloudsdkiamaccessanalyzer.v1.iamaccessanalyzer_client import IAMAccessAnalyzerClient
from huaweicloudsdkiamaccessanalyzer.v1.iamaccessanalyzer_async_client import IAMAccessAnalyzerAsyncClient

from huaweicloudsdkiamaccessanalyzer.v1.model.access_preview import AccessPreview
from huaweicloudsdkiamaccessanalyzer.v1.model.access_preview_id import AccessPreviewId
from huaweicloudsdkiamaccessanalyzer.v1.model.access_preview_status import AccessPreviewStatus
from huaweicloudsdkiamaccessanalyzer.v1.model.access_preview_summary import AccessPreviewSummary
from huaweicloudsdkiamaccessanalyzer.v1.model.analyzer_id import AnalyzerId
from huaweicloudsdkiamaccessanalyzer.v1.model.analyzer_name import AnalyzerName
from huaweicloudsdkiamaccessanalyzer.v1.model.analyzer_summary import AnalyzerSummary
from huaweicloudsdkiamaccessanalyzer.v1.model.analyzer_type import AnalyzerType
from huaweicloudsdkiamaccessanalyzer.v1.model.apply_archive_rule_request import ApplyArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.apply_archive_rule_response import ApplyArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.archive_rule_id import ArchiveRuleId
from huaweicloudsdkiamaccessanalyzer.v1.model.archive_rule_name import ArchiveRuleName
from huaweicloudsdkiamaccessanalyzer.v1.model.archive_rule_summary import ArchiveRuleSummary
from huaweicloudsdkiamaccessanalyzer.v1.model.configuration import Configuration
from huaweicloudsdkiamaccessanalyzer.v1.model.create_access_preview_req_body import CreateAccessPreviewReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.create_access_preview_request import CreateAccessPreviewRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.create_access_preview_response import CreateAccessPreviewResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.create_analyzer_req_body import CreateAnalyzerReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.create_analyzer_request import CreateAnalyzerRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.create_analyzer_response import CreateAnalyzerResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.create_archive_rule_req_body import CreateArchiveRuleReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.create_archive_rule_request import CreateArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.create_archive_rule_response import CreateArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.criterion import Criterion
from huaweicloudsdkiamaccessanalyzer.v1.model.current_count import CurrentCount
from huaweicloudsdkiamaccessanalyzer.v1.model.delete_analyzer_request import DeleteAnalyzerRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.delete_analyzer_response import DeleteAnalyzerResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.delete_archive_rule_request import DeleteArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.delete_archive_rule_response import DeleteArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.finding import Finding
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_condition import FindingCondition
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_filter import FindingFilter
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_id import FindingId
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_principal import FindingPrincipal
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_source_type import FindingSourceType
from huaweicloudsdkiamaccessanalyzer.v1.model.get_access_preview_request import GetAccessPreviewRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.get_access_preview_response import GetAccessPreviewResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.iam_agency import IAMAgency
from huaweicloudsdkiamaccessanalyzer.v1.model.limit import Limit
from huaweicloudsdkiamaccessanalyzer.v1.model.list_access_previews_request import ListAccessPreviewsRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_access_previews_response import ListAccessPreviewsResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.list_analyzers_request import ListAnalyzersRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_analyzers_response import ListAnalyzersResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.list_archive_rules_request import ListArchiveRulesRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_archive_rules_response import ListArchiveRulesResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.list_findings_req_body import ListFindingsReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.list_findings_request import ListFindingsRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_findings_response import ListFindingsResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.list_preview_findings_req_body import ListPreviewFindingsReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.list_preview_findings_request import ListPreviewFindingsRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_preview_findings_response import ListPreviewFindingsResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.location import Location
from huaweicloudsdkiamaccessanalyzer.v1.model.marker import Marker
from huaweicloudsdkiamaccessanalyzer.v1.model.next_marker import NextMarker
from huaweicloudsdkiamaccessanalyzer.v1.model.obs_bucket import OBSBucket
from huaweicloudsdkiamaccessanalyzer.v1.model.page_info import PageInfo
from huaweicloudsdkiamaccessanalyzer.v1.model.path_element import PathElement
from huaweicloudsdkiamaccessanalyzer.v1.model.policy_document import PolicyDocument
from huaweicloudsdkiamaccessanalyzer.v1.model.policy_type import PolicyType
from huaweicloudsdkiamaccessanalyzer.v1.model.position import Position
from huaweicloudsdkiamaccessanalyzer.v1.model.preview_finding import PreviewFinding
from huaweicloudsdkiamaccessanalyzer.v1.model.preview_status_reason import PreviewStatusReason
from huaweicloudsdkiamaccessanalyzer.v1.model.resource_owner_account import ResourceOwnerAccount
from huaweicloudsdkiamaccessanalyzer.v1.model.resource_type import ResourceType
from huaweicloudsdkiamaccessanalyzer.v1.model.show_analyzer_request import ShowAnalyzerRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.show_analyzer_response import ShowAnalyzerResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.show_archive_rule_request import ShowArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.show_archive_rule_response import ShowArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.show_finding_request import ShowFindingRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.show_finding_response import ShowFindingResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.span import Span
from huaweicloudsdkiamaccessanalyzer.v1.model.start_resource_scan_req_body import StartResourceScanReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.start_resource_scan_request import StartResourceScanRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.start_resource_scan_response import StartResourceScanResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.status_reason import StatusReason
from huaweicloudsdkiamaccessanalyzer.v1.model.substring import Substring
from huaweicloudsdkiamaccessanalyzer.v1.model.tag import Tag
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_key import TagKey
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_resource_req_body import TagResourceReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_resource_request import TagResourceRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_resource_response import TagResourceResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_value import TagValue
from huaweicloudsdkiamaccessanalyzer.v1.model.untag_resource_req_body import UntagResourceReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.untag_resource_request import UntagResourceRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.untag_resource_response import UntagResourceResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.update_archive_rule_req_body import UpdateArchiveRuleReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.update_archive_rule_request import UpdateArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.update_archive_rule_response import UpdateArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.update_findings_req_body import UpdateFindingsReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.update_findings_request import UpdateFindingsRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.update_findings_response import UpdateFindingsResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.urn import Urn
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_finding import ValidatePolicyFinding
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_req_body import ValidatePolicyReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_request import ValidatePolicyRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_resource_type import ValidatePolicyResourceType
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_response import ValidatePolicyResponse

==> huaweicloudsdkiamaccessanalyzer-3.1.101-py2.py3-none-any.whl: huaweicloudsdkiamaccessanalyzer/v1/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

from huaweicloudsdkiamaccessanalyzer.v1.iamaccessanalyzer_client import IAMAccessAnalyzerClient
from huaweicloudsdkiamaccessanalyzer.v1.iamaccessanalyzer_async_client import IAMAccessAnalyzerAsyncClient

from huaweicloudsdkiamaccessanalyzer.v1.model.access_preview import AccessPreview
from huaweicloudsdkiamaccessanalyzer.v1.model.access_preview_id import AccessPreviewId
from huaweicloudsdkiamaccessanalyzer.v1.model.access_preview_status import AccessPreviewStatus
from huaweicloudsdkiamaccessanalyzer.v1.model.access_preview_summary import AccessPreviewSummary
from huaweicloudsdkiamaccessanalyzer.v1.model.analyzer_id import AnalyzerId
from huaweicloudsdkiamaccessanalyzer.v1.model.analyzer_name import AnalyzerName
from huaweicloudsdkiamaccessanalyzer.v1.model.analyzer_summary import AnalyzerSummary
from huaweicloudsdkiamaccessanalyzer.v1.model.analyzer_type import AnalyzerType
from huaweicloudsdkiamaccessanalyzer.v1.model.analyzer_urn import AnalyzerUrn
from huaweicloudsdkiamaccessanalyzer.v1.model.apply_archive_rule_request import ApplyArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.apply_archive_rule_response import ApplyArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.archive_rule_id import ArchiveRuleId
from huaweicloudsdkiamaccessanalyzer.v1.model.archive_rule_name import ArchiveRuleName
from huaweicloudsdkiamaccessanalyzer.v1.model.archive_rule_summary import ArchiveRuleSummary
from huaweicloudsdkiamaccessanalyzer.v1.model.archive_rule_urn import ArchiveRuleUrn
from huaweicloudsdkiamaccessanalyzer.v1.model.configuration import Configuration
from huaweicloudsdkiamaccessanalyzer.v1.model.create_access_preview_req_body import CreateAccessPreviewReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.create_access_preview_request import CreateAccessPreviewRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.create_access_preview_response import CreateAccessPreviewResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.create_analyzer_req_body import CreateAnalyzerReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.create_analyzer_request import CreateAnalyzerRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.create_analyzer_response import CreateAnalyzerResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.create_archive_rule_req_body import CreateArchiveRuleReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.create_archive_rule_request import CreateArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.create_archive_rule_response import CreateArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.criterion import Criterion
from huaweicloudsdkiamaccessanalyzer.v1.model.current_count import CurrentCount
from huaweicloudsdkiamaccessanalyzer.v1.model.delete_analyzer_request import DeleteAnalyzerRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.delete_analyzer_response import DeleteAnalyzerResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.delete_archive_rule_request import DeleteArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.delete_archive_rule_response import DeleteArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.finding import Finding
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_condition import FindingCondition
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_filter import FindingFilter
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_id import FindingId
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_principal import FindingPrincipal
from huaweicloudsdkiamaccessanalyzer.v1.model.finding_source_type import FindingSourceType
from huaweicloudsdkiamaccessanalyzer.v1.model.iam_agency import IAMAgency
from huaweicloudsdkiamaccessanalyzer.v1.model.kms_cmk import KMSCmk
from huaweicloudsdkiamaccessanalyzer.v1.model.last_analyzed_resource_urn import LastAnalyzedResourceUrn
from huaweicloudsdkiamaccessanalyzer.v1.model.limit import Limit
from huaweicloudsdkiamaccessanalyzer.v1.model.list_access_preview_findings_request import ListAccessPreviewFindingsRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_access_preview_findings_response import ListAccessPreviewFindingsResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.list_access_previews_request import ListAccessPreviewsRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_access_previews_response import ListAccessPreviewsResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.list_analyzers_request import ListAnalyzersRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_analyzers_response import ListAnalyzersResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.list_archive_rules_request import ListArchiveRulesRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_archive_rules_response import ListArchiveRulesResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.list_findings_req_body import ListFindingsReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.list_findings_request import ListFindingsRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.list_findings_response import ListFindingsResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.list_preview_findings_req_body import ListPreviewFindingsReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.location import Location
from huaweicloudsdkiamaccessanalyzer.v1.model.marker import Marker
from huaweicloudsdkiamaccessanalyzer.v1.model.next_marker import NextMarker
from huaweicloudsdkiamaccessanalyzer.v1.model.obs_bucket import OBSBucket
from huaweicloudsdkiamaccessanalyzer.v1.model.organization_id import OrganizationId
from huaweicloudsdkiamaccessanalyzer.v1.model.page_info import PageInfo
from huaweicloudsdkiamaccessanalyzer.v1.model.path_element import PathElement
from huaweicloudsdkiamaccessanalyzer.v1.model.policy_document import PolicyDocument
from huaweicloudsdkiamaccessanalyzer.v1.model.policy_type import PolicyType
from huaweicloudsdkiamaccessanalyzer.v1.model.position import Position
from huaweicloudsdkiamaccessanalyzer.v1.model.preview_finding import PreviewFinding
from huaweicloudsdkiamaccessanalyzer.v1.model.preview_status_reason import PreviewStatusReason
from huaweicloudsdkiamaccessanalyzer.v1.model.resource_owner_account import ResourceOwnerAccount
from huaweicloudsdkiamaccessanalyzer.v1.model.resource_type import ResourceType
from huaweicloudsdkiamaccessanalyzer.v1.model.resource_urn import ResourceUrn
from huaweicloudsdkiamaccessanalyzer.v1.model.show_access_preview_request import ShowAccessPreviewRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.show_access_preview_response import ShowAccessPreviewResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.show_analyzer_request import ShowAnalyzerRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.show_analyzer_response import ShowAnalyzerResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.show_archive_rule_request import ShowArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.show_archive_rule_response import ShowArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.show_finding_request import ShowFindingRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.show_finding_response import ShowFindingResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.span import Span
from huaweicloudsdkiamaccessanalyzer.v1.model.start_resource_scan_req_body import StartResourceScanReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.start_resource_scan_request import StartResourceScanRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.start_resource_scan_response import StartResourceScanResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.status_reason import StatusReason
from huaweicloudsdkiamaccessanalyzer.v1.model.substring import Substring
from huaweicloudsdkiamaccessanalyzer.v1.model.tag import Tag
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_key import TagKey
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_resource_req_body import TagResourceReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_resource_request import TagResourceRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_resource_response import TagResourceResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.tag_value import TagValue
from huaweicloudsdkiamaccessanalyzer.v1.model.untag_resource_req_body import UntagResourceReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.untag_resource_request import UntagResourceRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.untag_resource_response import UntagResourceResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.update_archive_rule_req_body import UpdateArchiveRuleReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.update_archive_rule_request import UpdateArchiveRuleRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.update_archive_rule_response import UpdateArchiveRuleResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.update_findings_req_body import UpdateFindingsReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.update_findings_request import UpdateFindingsRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.update_findings_response import UpdateFindingsResponse
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_finding import ValidatePolicyFinding
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_req_body import ValidatePolicyReqBody
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_request import ValidatePolicyRequest
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_resource_type import ValidatePolicyResourceType
from huaweicloudsdkiamaccessanalyzer.v1.model.validate_policy_response import ValidatePolicyResponse
